X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/854e189f90dac9ba5e0239bca79aed64e8d6f46c..88f47aa77007c55ec0a8f1a48e429cb0ad050fe5:/include/wx/xrc/xh_radbt.h

diff --git a/include/wx/xrc/xh_radbt.h b/include/wx/xrc/xh_radbt.h
index 8a6fd4b1a9..889a4bde14 100644
--- a/include/wx/xrc/xh_radbt.h
+++ b/include/wx/xrc/xh_radbt.h
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_radbt.h
 // Purpose:     XML resource handler for radio buttons
 // Author:      Bob Mitchell
 // Created:     2000/03/21
 // RCS-ID:      $Id$
@@ -11,24 +11,20 @@
 #ifndef _WX_XH_RADBT_H_
 #define _WX_XH_RADBT_H_
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface "xh_radbt.h"
-#endif
-
 #include "wx/xrc/xmlres.h"
-#include "wx/defs.h"
 
-#if wxUSE_RADIOBOX
+#if wxUSE_XRC && wxUSE_RADIOBTN
 
-class WXXMLDLLEXPORT wxRadioButtonXmlHandler : public wxXmlResourceHandler
+class WXDLLIMPEXP_XRC wxRadioButtonXmlHandler : public wxXmlResourceHandler
 {
-DECLARE_DYNAMIC_CLASS(wxRadioButtonXmlHandler)
+    DECLARE_DYNAMIC_CLASS(wxRadioButtonXmlHandler)
+
 public:
     wxRadioButtonXmlHandler();
     virtual wxObject *DoCreateResource();
     virtual bool CanHandle(wxXmlNode *node);
 };
 
-#endif
+#endif // wxUSE_XRC && wxUSE_RADIOBOX
 
-#endif // _WX_XH_RADIOBUTTON_H_
+#endif // _WX_XH_RADBT_H_
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        xh_radbt.h
-// Purpose:     XML resource handler for radio buttons
+// Name:        wx/xrc/xh_radbt.h
+// Purpose:     XML resource handler for wxRadioButton
 // Author:      Bob Mitchell
 // Created:     2000/03/21